<!DOCTYPE html>
<html>
<head>
	<link href="{{url_for('panel.static', filename='css/bootstrap.min.css')}}" rel="stylesheet" id="bootstrap-css">
	<link href="{{url_for('panel.static', filename='css/login.css')}}" rel="stylesheet" id="bootstrap-css">
	<script src="{{url_for('panel.static', filename='js/bootstrap.min.js')}}"></script>
	<script src="{{url_for('panel.static', filename='js/jquery.min.js')}}"></script>
	<title>Login - Fardel</title>
</head>
<body>
    <div class="container">
        <div class="card card-container">
            <!-- <img class="profile-img-card" src="//lh3.googleusercontent.com/-6V8xOA6M7BA/AAAAAAAAAAI/AAAAAAAAAAA/rzlHcD0KYwo/photo.jpg?sz=120" alt="" /> -->
            <img id="profile-img" class="profile-img-card" src="//ssl.gstatic.com/accounts/ui/avatar_2x.png" />
            <p id="profile-name" class="profile-name-card"></p>
            <form class="form-signin" method="POST" action="">
                <span id="reauth-email" class="reauth-email"></span>
                <input type="email" name="email" id="inputEmail" class="form-control" placeholder="Email address" required autofocus>
                <input type="password" name="password" id="inputPassword" class="form-control" placeholder="Password" required>
                <div id="remember" class="checkbox">
                    <label>
                        <input type="checkbox" value="remember-me"> Remember me
                    </label>
                </div>
                <button class="btn btn-lg btn-primary btn-block btn-signin" type="submit">Sign in</button>
            </form><!-- /form -->
           <!--  <a href="#" class="forgot-password">
                Forgot the password?
            </a> -->
        </div><!-- /card-container -->
    </div><!-- /container -->
</body>
</html>