{% extends "panel_base.html" %}
{% import '_macros.html' as macros %}

{% block title %}داشبرد{% endblock %}
{% block header_title %}{{get_sitename()}} | داشبرد{% endblock %}


{% block content %}
{{macros.panel_box('عنوان', 'متن')}}
{% endblock %}